
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) INRIA 
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
#ifndef __CERRO_H__
#define __CERRO_H__
/*--------------------------------------------------------------------------*/ 
/*
* cerro
*/
void cerro(char *str);

#endif /*__CERRO_H__*/
/*--------------------------------------------------------------------------*/ 
